*************************************************
**** Hspice netlist to characterize process for
**** Differential Amplifier script 
**** by: Ethan Crain	February, 2004
**** High Speed Circuits and Systems Group
**** Massachusetts Institute of Technology
*************************************************

*************************************************
***** Information that user needs to update *****
*************************************************
**** both hdin and hdout are in meters
**** These are random numbers
**** Correct values for this process are not known
.param hdout=0.5e-6     ** Minimum s/d extension w/out sharing
.param hdin=0.5e-6      ** Minimum s/d extension w/ sharing

.prot
.include models/nmostt.m
.unprot

** For model libraries, use the following format
** .prot
** .lib '<path>/<model file>' TT
** .lib '<path>/<model file>' RES
** .unprot

.temp 27
.param vsupply=1.8
.param ibias=2m         ** Nominal bias current/2
.param w=1.8u		** Nominal device width
.param l=0.18u          ** Nominal device length (minimum by default)

*************************************************
**** End of information user needs to update ****
*************************************************
**** geo parameter specifies transistor topology
**** geo = 0: neither source or drain are shared
**** geo = 1: only the drain is shared
**** geo = 2: only the source is shared
**** geo = 3: both source and drain are shared
*************************************************

************** Module charbench **************
m0 vd vd gnd gnd
+    nmos l=l w=w m='1*d' geo=1
+    ad='w*hdin/2*d' as='w*d*hdout'
+    pd='2*hdin' ps='4*hdout+w*d'

.param d=2
Vsup vdd 0 vsupply
Vgnd gnd 0 0
Ibias vdd vd ibias ac 1u
.options post=1 delmax=5p relv=1e-6 reli=1e-6 relmos=1e-6 method=gear
.dc w 0.25u 100u 0.25u
.ac dec 1 1e1 1e2 sweep w 0.25u 100u 0.25u 
.op
.probe dc lx7(M0) lx8(M0) i(M0)
.probe ac lx18(M0) lx19(M0) lx20(M0) lx21(M0) lx22(M0) 

.alter (proc,temp)=(SS,-40)
.prot
.include models/nmosss.m
.unprot
.temp -40

.alter (proc,temp)=(SS,25)
.prot
.include models/nmosss.m
.unprot
.temp 25

.alter (proc,temp)=(SS,85)
.prot
.include models/nmosss.m
.unprot
.temp 85

.alter (proc,temp)=(TT,-40)
.prot
.include models/nmostt.m
.unprot
.temp -40

.alter (proc,temp)=(TT,25)
.prot
.include models/nmostt.m
.unprot
.temp 25

.alter (proc,temp)=(TT,85)
.prot
.include models/nmostt.m
.unprot
.temp 85

.alter (proc,temp)=(FF,-40)
.prot
.include models/nmosff.m
.unprot
.temp -40

.alter (proc,temp)=(FF,25)
.prot
.include models/nmosff.m
.unprot
.temp 25

.alter (proc,temp)=(FF,85)
.prot
.include models/nmosff.m
.unprot
.temp 85

.end

